import bpy
import blf
import bgl

draw_handle = None  # To store the draw handler reference

def draw_callback_px(self, context):
    """Draw callback to display 'OVERSCAN ENABLED' centered in the viewport."""
    if context.scene.get("overscan_enabled"):
        warning_text = "OVERSCAN ENABLED"

        # Set the font size before calculating dimensions
        blf.size(0, 24)
        overscan_warning_width, _ = blf.dimensions(0, warning_text)

        # Center the text in the viewport
        blf.position(0, context.region.width / 2 - overscan_warning_width / 2, context.region.height - 50, 0)

        # Draw the text
        blf.color(0, 1.0, 1.0, 0.0, 1.0)  # Yellow color (R, G, B, A)
        blf.draw(0, warning_text)

def enable_draw_callback(context):
    """Enables the draw handler for displaying text in the viewport."""
    global draw_handle
    if not draw_handle:
        draw_handle = bpy.types.SpaceView3D.draw_handler_add(
            draw_callback_px, (None, context), 'WINDOW', 'POST_PIXEL'
        )
        bpy.context.area.tag_redraw()

def disable_draw_callback():
    """Disables the draw handler and stops displaying text."""
    global draw_handle
    if draw_handle:
        bpy.types.SpaceView3D.draw_handler_remove(draw_handle, 'WINDOW')
        draw_handle = None
        bpy.context.area.tag_redraw()

def apply_overscan(scene, camera, overscan_value):
    """Applies overscan to the selected camera and saves original resolution and focal length."""
    res_x = scene.render.resolution_x
    res_y = scene.render.resolution_y

    # Save original resolution and focal length if not already saved
    if not scene.get("original_resolution"):
        scene["original_resolution"] = (res_x, res_y)
    if not scene.get("original_focal_length"):
        scene["original_focal_length"] = camera.data.lens

    # Adjust the camera lens and render resolution based on overscan value
    camera.data.lens = res_x * camera.data.lens / (res_x + 2 * overscan_value)
    scene.render.resolution_x = res_x + int(overscan_value) * 2
    scene.render.resolution_y = res_y + int(overscan_value) * 2

def restore_resolution(scene):
    """Restores the original resolution and focal length if they were saved."""
    if scene.get("original_resolution"):
        res_x, res_y = scene["original_resolution"]
        scene.render.resolution_x = res_x
        scene.render.resolution_y = res_y

    if scene.get("original_focal_length"):
        camera = scene.camera
        camera.data.lens = scene["original_focal_length"]